@@ -128,6 +128,11 @@ class Player:
         return chr(ord(self.country[0]) + Player._COUNTRY_FLAG_OFFSET) + \
             chr(ord(self.country[1]) + Player._COUNTRY_FLAG_OFFSET)
 
+    @property
+    def get_latest_plus_membership(self) -> PlusMembership:
+        """Order PlusMembership by date, get the last (most recent)"""
+        return sorted(self.plus_membership, key=lambda pm: pm.date)[-1]
+
     @property
     def sources(self):
         return \
