@@ -6,18 +6,21 @@ from slapp_py.helpers.str_helper import truncate, escape_characters
 
 # Mapping takes a list of tournament names and gives an organisation name
 SOURCE_ORGANISER_MAPPING: Dict[str, List[str]] = {
-    'inkling-performance-labs': ['-low-ink-', '-testing-grounds-' '-swim-or-sink-'],
-    'inktv': ['-bns-', '-swl-winter-snowflake-', '-splatoon-world-league-',
-              '-inktv-open-', '-extrafaganza-', '-inkvitational-'],
-    'sitback-saturdays': ['-sitback-saturdays-'],
-    'splatoon2': ['-splatoon-2-north-american-online-open-'],
-    'squidboards-splatoon-2-community-events': ['-sqss-', '-squidboards-splat-series-'],
-    'squid-spawning-grounds': ['-squid-spawning-grounds-'],
-    'fresh-start-cup': ['-fresh-start-cup-'],
-    'swift-second-saturdays': ['-sss-'],
-    'gamesetmatch': ['-gsm-'],
     'area-cup': ['-area-cup-'],
     'asquidmin': ['-turtlement-'],
+    'deep-sea-solutions': ['megalodon-cup-', '-minnow-cup-', 'trick-no-treat'],
+    'fresh-start-cup': ['-fresh-start-cup-'],
+    'gamesetmatch': ['-gsm-'],
+    'inkling-performance-labs': ['-low-ink-', '-testing-grounds-', '-swim-or-sink-'],
+    'inktv': ['-bns-', '-swl-winter-snowflake-', '-splatoon-world-league-', '-inktv-open-', '-extrafaganza-', '-inkvitational-'],
+    'little-squid-league': ['-little-squid-league-', '-little-squid-league-invitational-'],
+    'sitback-saturdays': ['-sitback-saturdays-'],
+    'splatcom': ['-armas-random-', '-duelos-', '-dúos-dittos-', 'splatcom-', '-suizo-latino-', '-torneo-de-', '-torneo-festivo-'],
+    'splatoon2': ['-splatoon-2-north-american-online-open-'],
+    'squid-south': ['squid-south-2v2-', '-squid-souths-halloween-2v2-'],
+    'squid-spawning-grounds': ['-squid-spawning-grounds-'],
+    'squidboards-splatoon-2-community-events': ['-sqss-', '-squidboards-splat-series-'],
+    'swift-second-saturdays': ['-sss-'],
 }
 
 
@@ -56,31 +59,37 @@ class SimpleSource:
 
         if len(source_name) > 11 and source_name.count('-') > 3:
             date = source_name[0:10].strip('- ')
+            default_tourney_name = source_name[11:].strip('- ')
         else:
             date = None
+            default_tourney_name = None
 
         for organiser, tourneys in SOURCE_ORGANISER_MAPPING.items():
             for tournament_name in tourneys:
                 if tournament_name in source_name:
                     m = re.search("-+([0-9a-fA-F]+)$", source_name, re.I)
                     if m:
-                        guid = m.groups()[0]
+                        # We always want to grab the last match as the id is at the end of the source name.
+                        guid = m.groups()[-1]
                         return date, organiser.strip('- '), tournament_name.strip('- '), \
                             f"https://battlefy.com/{organiser}//{guid}/info"
                     else:
                         return date, organiser.strip('- '), tournament_name.strip('- '), None
-        return date, None, None, None
+        return date, None, default_tourney_name, None
 
     def get_linked_date_display(self) -> str:
         """Return a markdown link with the truncated source date if available,
-        otherwise return its truncated text only."""
+        otherwise return its truncated_name only."""
         link = self.url
-        text = truncate(escape_characters(self.date or ''), 16, '…')
+        if self.date:
+            text = truncate(escape_characters(self.date), 16, '…')
+        else:
+            text = self.truncated_name
         return f"[{text}]({link})" if link else text
 
     def get_linked_name_display(self) -> str:
-        """Return a markdown link with the truncated source name if available,
-        otherwise return its truncated text only."""
+        """Return a markdown link with the truncated source name (date-name) if available,
+        otherwise return its truncated_name only."""
         link = self.url
         text = self.truncated_name
         return f"[{text}]({link})" if link else text
@@ -88,4 +97,9 @@ class SimpleSource:
     @property
     def truncated_name(self):
         """The source with the id removed and truncated down."""
-        return truncate(escape_characters(f"{(self.date or '')}-{self.tournament_name}"), 100, '…')
+        if self.date and self.tournament_name:
+            display_name = self.date + '-' + self.tournament_name
+        else:
+            # Strip the source id
+            display_name = re.sub("-+[0-9a-fA-F]+$", '', self.name)
+        return truncate(escape_characters(display_name), 100, '…')
