@@ -151,6 +151,7 @@ class SlappResponseObject:
                     logging.error(f"Source was not specified in JSON: {source}")
                 else:
                     result.append(simple_source)
+        result.sort(key=lambda s: s.name)  # Sorting by name guaranteed - all sources should have a name.
         return result
 
     def get_grouped_sources(self, sources: Union[Player, Team, List[UUID]]) -> Dict[str, List[SimpleSource]]:
@@ -164,8 +165,15 @@ class SlappResponseObject:
     def get_grouped_sources_text(self, sources: Union[Player, Team, List[UUID]]) -> List[str]:
         """Group the SimpleSource list for the specified sources/team/player by tourney name."""
         groups = self.get_grouped_sources(sources)
-        return [f"{tourney + ': ' if tourney else ''}{', '.join([simple_source.get_linked_date_display() for simple_source in simple_sources])}"
-                for tourney, simple_sources in groups.items()]
+        message = []
+        for tourney, simple_sources in groups.items():
+            group_key = tourney + ': ' if tourney else ''
+            group_value = (', '.join([simple_source.get_linked_date_display() for simple_source in simple_sources])
+                           if group_key
+                           else '\n'.join([simple_source.get_linked_name_display() for simple_source in simple_sources])
+                           )
+            message.append(f"{group_key}{group_value}")
+        return message
 
     def get_brackets_for_player(self, p: Player, source_id: str) -> List[Bracket]:
         """
@@ -187,7 +195,7 @@ class SlappResponseObject:
                     first_place_ids = [player_id.__str__() for player_id in
                                        bracket.placements.players_by_placement[1]]
                     if p.guid.__str__() in first_place_ids:
-                        result.append(bracket.name + ' in ' + simple_source.url)
+                        result.append(bracket.name + ' in ' + simple_source.get_linked_name_display())
 
         return result
 
